@@ -1,6 +1,6 @@
 
 .onAttach <- function(libname, pkgname) {
-    if (.cppVersion() < 201703L) {
+    if (.cppVersion() < 201703L) {      		# #nocov start
         packageStartupMessage(paste("This package requires a C++17 compiler for compilation but none",
                                     "was found so the package is not fully functional.\nPlease",
                                     "consider reinstalling with a better compiler."))
@@ -9,6 +9,6 @@
         packageStartupMessage(paste("This package requires a recent CPU type and supports several ",
                                     "models but not the one on this machine. You will likely ",
                                     "experience failure when trying to parse JSON documents."))
-    }
+    }							# #nocov end
 
 }
